# Bug Fix Pull Request

<!--
Before proceeding, please confirm that:
1. The changes have been discussed with the maintainers
2. A plan has been agreed upon
3. The related issue has been assigned to you
-->

## Description

<!-- Please include a summary of the bug fix -->

Fixes #<!-- issue number -->

## Checklist

- [ ] I have read the contributing guidelines
- [ ] I have added tests that verify the bug fix
- [ ] I have added an entry to CHANGES.rst describing the fix
- [ ] My code follows the code style of this project
- [ ] I have checked my code and corrected any misspellings

## How Has This Been Tested?

<!-- Please describe the tests that you ran to verify your changes -->

## Steps to Reproduce (original bug)

<!-- Please provide steps to reproduce the bug you fixed -->

1.
2.
3.

## Additional Notes

<!-- Add any other context about the PR here -->
